@@ -146,6 +146,26 @@ sebie_update_view(struct sebie_s *sebie)
 }
 
 
+void
+sebie_error_popup(struct sebie_s *sebie, gchar *error_str)
+{
+  GtkWidget *dialog = gtk_message_dialog_new (GTK_WINDOW(sebie->view.window1),
+					      GTK_DIALOG_DESTROY_WITH_PARENT,
+					      GTK_MESSAGE_ERROR,
+					      GTK_BUTTONS_CLOSE,
+					      error_str);
+#if 1
+  // modal dialog: you must click to resume
+  gtk_dialog_run (GTK_DIALOG (dialog));
+  gtk_widget_destroy (dialog);
+#else
+  // non modal dialog: application will run further
+  g_signal_connect_swapped (GTK_OBJECT (dialog), "response",
+			    G_CALLBACK (gtk_widget_destroy),
+			    GTK_OBJECT (dialog));
+  gtk_widget_show (dialog);
+#endif
+}
 
 
 void
