@@ -24,19 +24,22 @@
 typedef enum sebie_config_type_e {
   CONFIG_END,
   CONFIG_INTEGER,
+  CONFIG_DOUBLE,
   CONFIG_STRING
 } sebie_config_type;
 
 typedef struct sebie_config_spec_s {
   char *name;
   sebie_config_type type;
-  union a {
-    int *integer;
-    char **string;
+  union storage_u {
+    int    *integer;
+    double *doublev;
+    char   **string;
   } storage;
-  union b {
-    int integer;
-    char *string;
+  union defvalue_u {
+    int    integer;
+    double doublev;
+    char   *string;
   } defvalue;
 } sebie_config_spec;
 
