@@ -24,6 +24,6 @@
 #include <gdk/gdk.h>
 
 void
-sebie_set_string(gchar **old_text, gchar *new_text);
+sebie_set_string(gchar **old_text, const gchar *new_text);
 
 #endif /* _SEBIE_HELPERS_H_ */
