@@ -35,7 +35,8 @@ GtkWidget *
 init_sebie_view(struct sebie_s *sebie)
 {
   GtkWidget *tmp_toolbar_icon;
-  
+  GtkAdjustment *gamma_adjustment;
+ 
   sebie->view.window1 = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gchar * window1_title = "SeBIE " PACKAGE_VERSION ;
   gtk_window_set_title (GTK_WINDOW (sebie->view.window1), window1_title);
@@ -171,12 +172,21 @@ init_sebie_view(struct sebie_s *sebie)
   gtk_toolbar_append_widget (GTK_TOOLBAR (sebie->view.toolbar1), sebie->view.label_selection_gamma, NULL, NULL);
   gtk_label_set_justify (GTK_LABEL (sebie->view.label_selection_gamma), GTK_JUSTIFY_LEFT);
 
+#if 1
+  gamma_adjustment = (GtkAdjustment *)gtk_adjustment_new(1.0, 0.1, 3.0, 0.1, 0.1, 0.0);
+  sebie->view.entry_selection_gamma = gtk_spin_button_new(gamma_adjustment,
+							  0.0,
+							  1);
+  
+#else
   sebie->view.entry_selection_gamma = gtk_entry_new ();
+#endif
   gtk_widget_show (sebie->view.entry_selection_gamma);
   gtk_toolbar_append_widget (GTK_TOOLBAR (sebie->view.toolbar1), sebie->view.entry_selection_gamma, NULL, NULL);
   gtk_widget_set_size_request (sebie->view.entry_selection_gamma, 50, 20);
   gtk_entry_set_max_length (GTK_ENTRY (sebie->view.entry_selection_gamma), 5);
 
+
 #if 0
   sebie->view.button7 = gtk_toolbar_append_element (GTK_TOOLBAR (sebie->view.toolbar1),
                                 GTK_TOOLBAR_CHILD_BUTTON,
@@ -288,6 +298,9 @@ init_sebie_view(struct sebie_s *sebie)
   g_signal_connect ((gpointer) sebie->view.button_fac_swap, "clicked",
                     G_CALLBACK (on_button_fac_swap),
                     sebie);
+  g_signal_connect ((gpointer) sebie->view.drawingarea1, "expose_event",
+                    G_CALLBACK (on_drawingarea1_expose_event),
+                    sebie);
   g_signal_connect ((gpointer) sebie->view.drawingarea1, "button_press_event",
                     G_CALLBACK (on_drawingarea1_button_press_event),
                     sebie);
